translate.filters.checks.SeriousFilterFailure

Package translate :: Package filters :: Module checks :: Class SeriousFilterFailure |
[hide private]
[frames] | no frames]

# Class SeriousFilterFailure

source code

This exception signals that a Filter didn't pass, and the bad translation might break an application (so the string will be marked fuzzy)

Instance Methods | [hide private]
Inherited from `FilterFailure`: `__init__` Inherited from `exceptions.Exception`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__str__` Inherited from `object`: `__hash__`, `__reduce_ex__`

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`